@@ -48,6 +48,9 @@ test_that("discrete fill works", {
   midnights <- fill_base +
     scale_fill_taylor_d(album = "midnights")
 
+  ttpd <- fill_base +
+    scale_fill_taylor_d(album = "THE TORTURED POETS DEPARTMENT")
+
   vdiffr::expect_doppelganger("taylor-swift-fill-d", taylor_swift)
   vdiffr::expect_doppelganger("fearless-fill-d", fearless)
   vdiffr::expect_doppelganger("fearless-tv-fill-d", fearless_tv)
@@ -62,6 +65,7 @@ test_that("discrete fill works", {
   vdiffr::expect_doppelganger("folklore-fill-d", folklore)
   vdiffr::expect_doppelganger("evermore-fill-d", evermore)
   vdiffr::expect_doppelganger("midnights-fill-d", midnights)
+  vdiffr::expect_doppelganger("ttpd-fill-d", ttpd)
 })
 
 test_that("discrete color works", {
@@ -111,6 +115,9 @@ test_that("discrete color works", {
   midnights <- color_base +
     scale_color_taylor_d(album = "midnights")
 
+  ttpd <- color_base +
+    scale_color_taylor_d(album = "the tortured poets department")
+
   vdiffr::expect_doppelganger("taylor-swift-color-d", taylor_swift)
   vdiffr::expect_doppelganger("fearless-color-d", fearless)
   vdiffr::expect_doppelganger("fearless-tv-color-d", fearless_tv)
@@ -125,6 +132,7 @@ test_that("discrete color works", {
   vdiffr::expect_doppelganger("folklore-color-d", folklore)
   vdiffr::expect_doppelganger("evermore-color-d", evermore)
   vdiffr::expect_doppelganger("midnights-color-d", midnights)
+  vdiffr::expect_doppelganger("ttpd-color-d", ttpd)
 })
 
 test_that("continuous fill works", {
@@ -208,6 +216,9 @@ test_that("continuous fill works", {
   midnights <- fill_base +
     scale_fill_taylor_c(album = "midnights")
 
+  ttpd <- fill_base +
+    scale_fill_taylor_c(album = "tortured poets")
+
   vdiffr::expect_doppelganger("taylor-swift-fill-c", taylor_swift)
   vdiffr::expect_doppelganger("fearless-fill-c", fearless)
   vdiffr::expect_doppelganger("fearless-tv-fill-c", fearless_tv)
@@ -222,6 +233,7 @@ test_that("continuous fill works", {
   vdiffr::expect_doppelganger("folklore-fill-c", folklore)
   vdiffr::expect_doppelganger("evermore-fill-c", evermore)
   vdiffr::expect_doppelganger("midnights-fill-c", midnights)
+  vdiffr::expect_doppelganger("ttpd-fill-c", ttpd)
 })
 
 test_that("continuous color works", {
@@ -398,6 +410,9 @@ test_that("continuous color works", {
   midnights <- color_base +
     scale_color_taylor_c(album = "midnights")
 
+  ttpd <- color_base +
+    scale_color_taylor_c(album = "Tortured Poets")
+
   vdiffr::expect_doppelganger("taylor-swift-color-c", taylor_swift)
   vdiffr::expect_doppelganger("fearless-color-c", fearless)
   vdiffr::expect_doppelganger("fearless-tv-color-c", fearless_tv)
@@ -412,6 +427,7 @@ test_that("continuous color works", {
   vdiffr::expect_doppelganger("folklore-color-c", folklore)
   vdiffr::expect_doppelganger("evermore-color-c", evermore)
   vdiffr::expect_doppelganger("midnights-color-c", midnights)
+  vdiffr::expect_doppelganger("ttpd-color-c", ttpd)
 })
 
 test_that("binned fill works", {
@@ -461,6 +477,9 @@ test_that("binned fill works", {
   midnights <- fill_base +
     scale_fill_taylor_b(album = "midnights")
 
+  ttpd <- fill_base +
+    scale_fill_taylor_b(album = "The Tortured Poets Department")
+
   vdiffr::expect_doppelganger("taylor-swift-fill-b", taylor_swift)
   vdiffr::expect_doppelganger("fearless-fill-b", fearless)
   vdiffr::expect_doppelganger("fearless-tv-fill-b", fearless_tv)
@@ -475,6 +494,7 @@ test_that("binned fill works", {
   vdiffr::expect_doppelganger("folklore-fill-b", folklore)
   vdiffr::expect_doppelganger("evermore-fill-b", evermore)
   vdiffr::expect_doppelganger("midnights-fill-b", midnights)
+  vdiffr::expect_doppelganger("ttpd-fill-b", ttpd)
 })
 
 test_that("binned color work", {
@@ -524,6 +544,9 @@ test_that("binned color work", {
   midnights <- color_base +
     scale_color_taylor_b(album = "midnights")
 
+  ttpd <- color_base +
+    scale_color_taylor_b(album = "the tortured poets department")
+
   vdiffr::expect_doppelganger("taylor-swift-color-b", taylor_swift)
   vdiffr::expect_doppelganger("fearless-color-b", fearless)
   vdiffr::expect_doppelganger("fearless-tv-color-b", fearless_tv)
@@ -538,6 +561,7 @@ test_that("binned color work", {
   vdiffr::expect_doppelganger("folklore-color-b", folklore)
   vdiffr::expect_doppelganger("evermore-color-b", evermore)
   vdiffr::expect_doppelganger("midnights-color-b", midnights)
+  vdiffr::expect_doppelganger("ttpd-color-b", ttpd)
 })
 
 test_that("album scale works", {
